@@ -29,9 +29,9 @@ public:
     void saveGravatarPixmap(const Hash &hash, const QPixmap &pixmap);
     void saveMissingGravatar(const Hash &hash);
 
-    Q_REQUIRED_RESULT QPixmap loadGravatarPixmap(const Hash &hash, bool &gravatarStored);
+    [[nodiscard]] QPixmap loadGravatarPixmap(const Hash &hash, bool &gravatarStored);
 
-    Q_REQUIRED_RESULT int maximumSize() const;
+    [[nodiscard]] int maximumSize() const;
     void setMaximumSize(int maximumSize);
 
     void clear();
