@@ -11,6 +11,7 @@
 class QCheckBox;
 class QPushButton;
 class KPluralHandlingSpinBox;
+class KConfigDialogManager;
 namespace Gravatar
 {
 /** Gravatar settings widget. */
@@ -25,11 +26,12 @@ public:
     void load();
 
 private:
-    void slotClearGravatarCache();
+    GRAVATAR_NO_EXPORT void slotClearGravatarCache();
     QCheckBox *mUseDefaultPixmap = nullptr;
     QPushButton *mClearGravatarCache = nullptr;
     KPluralHandlingSpinBox *mGravatarCacheSize = nullptr;
     QCheckBox *mUseLibravatar = nullptr;
     QCheckBox *mFallbackGravatar = nullptr;
+    KConfigDialogManager *m_configDialogManager = nullptr;
 };
 }
